<?php

if ( !defined( 'FW' ) )
	die( 'Forbidden' );

class FW_Option_Type_NewIcon extends FW_Option_Type {

	/**
	 * Prevent enqueue same font style twice, in case it is used in multiple sets
	 * @var array
	 */
	private $enqueued_font_styles = array();

	public function get_type() {
		return 'new-icon';
	}

	/**
	 * @internal
	 */
	public function _get_backend_width_type() {
		return 'full';
	}

	/**
	 * @internal
	 * {@inheritdoc}
	 */
	protected function _enqueue_static( $id, $option, $data ) {
 
		$uri = BINDUZ_THEME_URI . '/framework-customizations/option-types/' . $this->get_type() . '/static';

		wp_enqueue_style(
		'fw-option-' . $this->get_type(), $uri . '/css/backend.css'
		);

		wp_enqueue_script(
		'fw-option-' . $this->get_type(), $uri . '/js/backend.js', array( 'jquery', 'fw-events' ), fw()->manifest->get_version()
		);

		$sets = $this->get_sets();

		if ( isset( $sets[ $option[ 'set' ] ] ) ) {
			$set = $sets[ $option[ 'set' ] ];

			unset( $sets );

			/**
			 * user hash as array key instead of src, because src can be a very long data-url string
			 */
			$style_hash = md5( $set[ 'font-style-src' ] );

			if ( !isset( $this->enqueued_font_styles[ $style_hash ] ) ) {
				wp_enqueue_style(
				"fw-option-type-{$this->get_type()}-font-{$option[ 'set' ]}", $set[ 'font-style-src' ], array(), fw()->manifest->get_version()
				);

				$this->enqueued_font_styles[ $style_hash ] = true;
			}
		}

		return true;
	}

	/**
	 * @internal
	 */
	protected function _render( $id, $option, $data ) {

		
		$sets = $this->get_sets();

		if ( isset( $sets[ $option[ 'set' ] ] ) ) {
			$set = $sets[ $option[ 'set' ] ];
		} else {
			$set = $this->generate_unknown_set( $data[ 'value' ] );
		}

		unset( $sets );

		$option[ 'attr' ][ 'value' ] = (string) $data[ 'value' ];

		return fw_render_view( BINDUZ_THEME_DIR . '/framework-customizations/option-types/' . $this->get_type() . '/view.php', compact( 'id', 'option', 'data', 'set' ) );
	}

	/**
	 * @internal
	 */
	protected function _get_value_from_input( $option, $input_value ) {
		if ( is_null( $input_value ) ) {
			return $option[ 'value' ];
		}

		$sets = $this->get_sets();

		if ( isset( $sets[ $option[ 'set' ] ] ) ) {
			$set = $sets[ $option[ 'set' ] ];
		} else {
			$set = $this->generate_unknown_set( $input_value );
		}

		unset( $sets );

		if ( !isset( $set[ 'icons' ][ $input_value ] ) ) {
			$input_value = $option[ 'value' ];
		}

		return (string) $input_value;
	}

	/**
	 * @internal
	 */
	protected function _get_defaults() {
		return array(
			'value'	 => '',
			'set'	 => 'font-awesome',
		);
	}

	private function get_sets() {
		$cache_key = 'fw_option_type_icon/sets';

		try {
			return FW_Cache::get( $cache_key );
		} catch ( FW_Cache_Not_Found_Exception $e ) {
			$sets = apply_filters( 'fw_option_type_icon_sets', $this->get_default_sets() );
			// do not allow overwrite default sets
			$sets = array_merge( $sets, $this->get_default_sets() );

			FW_Cache::set( $cache_key, $sets );

			return $sets;
		}
	}

	private function generate_unknown_set( $icon ) {
		return array(
			'font-style-src'	 => 'data:text/css;charset=utf-8;base64,LyoqLw==', // fixme: WP will transform this to `http://domain.com/data:text/css;...`
			'container-class'	 => '',
			'groups'			 => array(
				'unknown' => esc_html__( 'Unknown Set', 'binduz' ),
			),
			'icons'				 => array(
				$icon => array( 'group' => 'unknown' ),
			),
		);
	}

	private function get_default_sets() {
		return array(
			    'font-awesome' => array( // http://fortawesome.github.io/Font-Awesome/icons
				'font-style-src'	 => BINDUZ_CSS . '/font-awesome.min.css',
				'container-class'	 => 'fa-lg', 
				'groups'			 => array(
					'brand'	    => esc_html__( 'Brand', 'binduz' ),
					'web-application'	=> esc_html__( 'web-application', 'binduz' ),
				
				),
				'icons'				 => [
					'fas fa-address-book'=>array( 'group' => 'brand' ),
					'fas fa-address-card'=>array( 'group' => 'web-application' ),
					'fas fa-adjust'=>array( 'group' => 'web-application' ),
					'fas fa-align-center'=>array( 'group' => 'web-application' ),
					'fas fa-align-justify'=>array( 'group' => 'web-application' ),
					'fas fa-align-left'=>array( 'group' => 'web-application' ),
					'fas fa-align-right'=>array( 'group' => 'web-application' ),
					'fas fa-allergies'=>array( 'group' => 'web-application' ),
					'fas fa-ambulance'=>array( 'group' => 'web-application' ),
					'fas fa-american-sign-language-interpreting'=>array( 'group' => 'web-application' ),
					'fas fa-anchor'=>array( 'group' => 'web-application' ),
					'fas fa-angle-double-down'=>array( 'group' => 'web-application' ),
					'fas fa-angle-double-left'=>array( 'group' => 'web-application' ),
					'fas fa-angle-double-right'=>array( 'group' => 'web-application' ),
					'fas fa-angle-double-up'=>array( 'group' => 'web-application' ),
					'fas fa-angle-down'=>array( 'group' => 'web-application' ),
					'fas fa-angle-left'=>array( 'group' => 'web-application' ),
					'fas fa-angle-right'=>array( 'group' => 'web-application' ),
					'fas fa-angle-up'=>array( 'group' => 'web-application' ),
					'fas fa-archive'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-alt-circle-down'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-alt-circle-left'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-alt-circle-right'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-alt-circle-up'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-circle-down'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-circle-left'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-circle-right'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-circle-up'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-down'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-left'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-right'=>array( 'group' => 'web-application' ),
					'fas fa-arrow-up'=>array( 'group' => 'web-application' ),
					'fas fa-arrows-alt'=>array( 'group' => 'web-application' ),
					'fas fa-arrows-alt-h'=>array( 'group' => 'web-application' ),
					'fas fa-arrows-alt-v'=>array( 'group' => 'web-application' ),
					'fas fa-assistive-listening-systems'=>array( 'group' => 'web-application' ),
					'fas fa-asterisk'=>array( 'group' => 'web-application' ),
					'fas fa-at'=>array( 'group' => 'web-application' ),
					'fas fa-audio-description'=>array( 'group' => 'web-application' ),
					'fas fa-backward'=>array( 'group' => 'web-application' ),
					'fas fa-balance-scale'=>array( 'group' => 'web-application' ),
					'fas fa-ban'=>array( 'group' => 'web-application' ),
					'fas fa-band-aid'=>array( 'group' => 'web-application' ),
					'fas fa-barcode'=>array( 'group' => 'web-application' ),
					'fas fa-bars'=>array( 'group' => 'web-application' ),
					'fas fa-baseball-ball'=>array( 'group' => 'web-application' ),
					'fas fa-basketball-ball'=>array( 'group' => 'web-application' ),
					'fas fa-bath'=>array( 'group' => 'web-application' ),
					'fas fa-battery-empty'=>array( 'group' => 'web-application' ),
					'fas fa-battery-full'=>array( 'group' => 'web-application' ),
					'fas fa-battery-half'=>array( 'group' => 'web-application' ),
					'fas fa-battery-quarter'=>array( 'group' => 'web-application' ),
					'fas fa-battery-three-quarters'=>array( 'group' => 'web-application' ),
					'fas fa-bed'=>array( 'group' => 'web-application' ),
					'fas fa-beer'=>array( 'group' => 'web-application' ),
					'fas fa-bell'=>array( 'group' => 'web-application' ),
					'fas fa-bell-slash'=>array( 'group' => 'web-application' ),
					'fas fa-bicycle'=>array( 'group' => 'web-application' ),
					'fas fa-binoculars'=>array( 'group' => 'web-application' ),
					'fas fa-birthday-cake'=>array( 'group' => 'web-application' ),
					'fas fa-blender'=>array( 'group' => 'web-application' ),
					'fas fa-blind'=>array( 'group' => 'web-application' ),
					'fas fa-bold'=>array( 'group' => 'web-application' ),
					'fas fa-bolt'=>array( 'group' => 'web-application' ),
					'fas fa-bomb'=>array( 'group' => 'web-application' ),
					'fas fa-book'=>array( 'group' => 'web-application' ),
					'fas fa-book-open'=>array( 'group' => 'web-application' ),
					'fas fa-bookmark'=>array( 'group' => 'web-application' ),
					'fas fa-bowling-ball'=>array( 'group' => 'web-application' ),
					'fas fa-box'=>array( 'group' => 'web-application' ),
					'fas fa-box-open'=>array( 'group' => 'web-application' ),
					'fas fa-boxes'=>array( 'group' => 'web-application' ),
					'fas fa-braille'=>array( 'group' => 'web-application' ),
					'fas fa-briefcase'=>array( 'group' => 'web-application' ),
					'fas fa-briefcase-medical'=>array( 'group' => 'web-application' ),
					'fas fa-broadcast-tower'=>array( 'group' => 'web-application' ),
					'fas fa-broom'=>array( 'group' => 'web-application' ),
					'fas fa-bug'=>array( 'group' => 'web-application' ),
					'fas fa-building'=>array( 'group' => 'web-application' ),
					'fas fa-bullhorn'=>array( 'group' => 'web-application' ),
					'fas fa-bullseye'=>array( 'group' => 'web-application' ),
					'fas fa-burn'=>array( 'group' => 'web-application' ),
					'fas fa-bus'=>array( 'group' => 'web-application' ),
					'fas fa-calculator'=>array( 'group' => 'web-application' ),
					'fas fa-calendar'=>array( 'group' => 'web-application' ),
					'fas fa-calendar-alt'=>array( 'group' => 'web-application' ),
					'fas fa-calendar-check'=>array( 'group' => 'web-application' ),
					'fas fa-calendar-minus'=>array( 'group' => 'web-application' ),
					'fas fa-calendar-plus'=>array( 'group' => 'web-application' ),
					'fas fa-calendar-times'=>array( 'group' => 'web-application' ),
					'fas fa-camera'=>array( 'group' => 'web-application' ),
					'fas fa-camera-retro'=>array( 'group' => 'web-application' ),
					'fas fa-capsules'=>array( 'group' => 'web-application' ),
					'fas fa-car'=>array( 'group' => 'web-application' ),
					'fas fa-caret-down'=>array( 'group' => 'web-application' ),
					'fas fa-caret-left'=>array( 'group' => 'web-application' ),
					'fas fa-caret-right'=>array( 'group' => 'web-application' ),
					'fas fa-caret-square-down'=>array( 'group' => 'web-application' ),
					'fas fa-caret-square-left'=>array( 'group' => 'web-application' ),
					'fas fa-caret-square-right'=>array( 'group' => 'web-application' ),
					'fas fa-caret-square-up'=>array( 'group' => 'web-application' ),
					'fas fa-caret-up'=>array( 'group' => 'web-application' ),
					'fas fa-cart-arrow-down'=>array( 'group' => 'web-application' ),
					'fas fa-cart-plus'=>array( 'group' => 'web-application' ),
					'fas fa-certificate'=>array( 'group' => 'web-application' ),
					'fas fa-chalkboard'=>array( 'group' => 'web-application' ),
					'fas fa-chalkboard-teacher'=>array( 'group' => 'web-application' ),
					'fas fa-chart-area'=>array( 'group' => 'web-application' ),
					'fas fa-chart-bar'=>array( 'group' => 'web-application' ),
					'fas fa-chart-line'=>array( 'group' => 'web-application' ),
					'fas fa-chart-pie'=>array( 'group' => 'web-application' ),
					'fas fa-check'=>array( 'group' => 'web-application' ),
					'fas fa-check-circle'=>array( 'group' => 'web-application' ),
					'fas fa-check-square'=>array( 'group' => 'web-application' ),
					'fas fa-chess'=>array( 'group' => 'web-application' ),
					'fas fa-chess-bishop'=>array( 'group' => 'web-application' ),
					'fas fa-chess-board'=>array( 'group' => 'web-application' ),
					'fas fa-chess-king'=>array( 'group' => 'web-application' ),
					'fas fa-chess-knight'=>array( 'group' => 'web-application' ),
					'fas fa-chess-pawn'=>array( 'group' => 'web-application' ),
					'fas fa-chess-queen'=>array( 'group' => 'web-application' ),
					'fas fa-chess-rook'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-circle-down'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-circle-left'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-circle-right'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-circle-up'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-down'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-left'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-right'=>array( 'group' => 'web-application' ),
					'fas fa-chevron-up'=>array( 'group' => 'web-application' ),
					'fas fa-child'=>array( 'group' => 'web-application' ),
					'fas fa-church'=>array( 'group' => 'web-application' ),
					'fas fa-circle'=>array( 'group' => 'web-application' ),
					'fas fa-circle-notch'=>array( 'group' => 'web-application' ),
					'fas fa-clipboard'=>array( 'group' => 'web-application' ),
					'fas fa-clipboard-check'=>array( 'group' => 'web-application' ),
					'fas fa-clipboard-list'=>array( 'group' => 'web-application' ),
					'fas fa-clock'=>array( 'group' => 'web-application' ),
					'fas fa-clone'=>array( 'group' => 'web-application' ),
					'fas fa-closed-captioning'=>array( 'group' => 'web-application' ),
					'fas fa-cloud'=>array( 'group' => 'web-application' ),
					'fas fa-cloud-download-alt'=>array( 'group' => 'web-application' ),
					'fas fa-cloud-upload-alt'=>array( 'group' => 'web-application' ),
					'fas fa-code'=>array( 'group' => 'web-application' ),
					'fas fa-code-branch'=>array( 'group' => 'web-application' ),
					'fas fa-coffee'=>array( 'group' => 'web-application' ),
					'fas fa-cog'=>array( 'group' => 'web-application' ),
					'fas fa-cogs'=>array( 'group' => 'web-application' ),
					'fas fa-coins'=>array( 'group' => 'web-application' ),
					'fas fa-columns'=>array( 'group' => 'web-application' ),
					'fas fa-comment'=>array( 'group' => 'web-application' ),
					'fas fa-comment-alt'=>array( 'group' => 'web-application' ),
					'fas fa-comment-dots'=>array( 'group' => 'web-application' ),
					'fas fa-comment-slash'=>array( 'group' => 'web-application' ),
					'fas fa-comments'=>array( 'group' => 'web-application' ),
					'fas fa-compact-disc'=>array( 'group' => 'web-application' ),
					'fas fa-compass'=>array( 'group' => 'web-application' ),
					'fas fa-compress'=>array( 'group' => 'web-application' ),
					'fas fa-copy'=>array( 'group' => 'web-application' ),
					'fas fa-copyright'=>array( 'group' => 'web-application' ),
					'fas fa-couch'=>array( 'group' => 'web-application' ),
					'fas fa-credit-card'=>array( 'group' => 'web-application' ),
					'fas fa-crop'=>array( 'group' => 'web-application' ),
					'fas fa-crosshairs'=>array( 'group' => 'web-application' ),
					'fas fa-crow'=>array( 'group' => 'web-application' ),
					'fas fa-crown'=>array( 'group' => 'web-application' ),
					'fas fa-cube'=>array( 'group' => 'web-application' ),
					'fas fa-cubes'=>array( 'group' => 'web-application' ),
					'fas fa-cut'=>array( 'group' => 'web-application' ),
					'fas fa-database'=>array( 'group' => 'web-application' ),
					'fas fa-deaf'=>array( 'group' => 'web-application' ),
					'fas fa-desktop'=>array( 'group' => 'web-application' ),
					'fas fa-diagnoses'=>array( 'group' => 'web-application' ),
					'fas fa-dice'=>array( 'group' => 'web-application' ),
					'fas fa-dice-five'=>array( 'group' => 'web-application' ),
					'fas fa-dice-four'=>array( 'group' => 'web-application' ),
					'fas fa-dice-one'=>array( 'group' => 'web-application' ),
					'fas fa-dice-six'=>array( 'group' => 'web-application' ),
					'fas fa-dice-three'=>array( 'group' => 'web-application' ),
					'fas fa-dice-two'=>array( 'group' => 'web-application' ),
					'fas fa-divide'=>array( 'group' => 'web-application' ),
					'fas fa-dna'=>array( 'group' => 'web-application' ),
					'fas fa-dollar-sign'=>array( 'group' => 'web-application' ),
					'fas fa-dolly'=>array( 'group' => 'web-application' ),
					'fas fa-dolly-flatbed'=>array( 'group' => 'web-application' ),
					'fas fa-donate'=>array( 'group' => 'web-application' ),
					'fas fa-door-closed'=>array( 'group' => 'web-application' ),
					'fas fa-door-open'=>array( 'group' => 'web-application' ),
					'fas fa-dot-circle'=>array( 'group' => 'web-application' ),
					'fas fa-dove'=>array( 'group' => 'web-application' ),
					'fas fa-download'=>array( 'group' => 'web-application' ),
					'fas fa-dumbbell'=>array( 'group' => 'web-application' ),
					'fas fa-edit'=>array( 'group' => 'web-application' ),
					'fas fa-eject'=>array( 'group' => 'web-application' ),
					'fas fa-ellipsis-h'=>array( 'group' => 'web-application' ),
					'fas fa-ellipsis-v'=>array( 'group' => 'web-application' ),
					'fas fa-envelope'=>array( 'group' => 'web-application' ),
					'fas fa-envelope-open'=>array( 'group' => 'web-application' ),
					'fas fa-envelope-square'=>array( 'group' => 'web-application' ),
					'fas fa-equals'=>array( 'group' => 'web-application' ),
					'fas fa-eraser'=>array( 'group' => 'web-application' ),
					'fas fa-euro-sign'=>array( 'group' => 'web-application' ),
					'fas fa-exchange-alt'=>array( 'group' => 'web-application' ),
					'fas fa-exclamation'=>array( 'group' => 'web-application' ),
					'fas fa-exclamation-circle'=>array( 'group' => 'web-application' ),
					'fas fa-exclamation-triangle'=>array( 'group' => 'web-application' ),
					'fas fa-expand'=>array( 'group' => 'web-application' ),
					'fas fa-expand-arrows-alt'=>array( 'group' => 'web-application' ),
					'fas fa-external-link-alt'=>array( 'group' => 'web-application' ),
					'fas fa-external-link-square-alt'=>array( 'group' => 'web-application' ),
					'fas fa-eye'=>array( 'group' => 'web-application' ),
					'fas fa-eye-dropper'=>array( 'group' => 'web-application' ),
					'fas fa-eye-slash'=>array( 'group' => 'web-application' ),
					'fas fa-fast-backward'=>array( 'group' => 'web-application' ),
					'fas fa-fast-forward'=>array( 'group' => 'web-application' ),
					'fas fa-fax'=>array( 'group' => 'web-application' ),
					'fas fa-feather'=>array( 'group' => 'web-application' ),
					'fas fa-female'=>array( 'group' => 'web-application' ),
					'fas fa-fighter-jet'=>array( 'group' => 'web-application' ),
					'fas fa-file'=>array( 'group' => 'web-application' ),
					'fas fa-file-alt'=>array( 'group' => 'web-application' ),
					'fas fa-file-archive'=>array( 'group' => 'web-application' ),
					'fas fa-file-audio'=>array( 'group' => 'web-application' ),
					'fas fa-file-code'=>array( 'group' => 'web-application' ),
					'fas fa-file-excel'=>array( 'group' => 'web-application' ),
					'fas fa-file-image'=>array( 'group' => 'web-application' ),
					'fas fa-file-medical'=>array( 'group' => 'web-application' ),
					'fas fa-file-medical-alt'=>array( 'group' => 'web-application' ),
					'fas fa-file-pdf'=>array( 'group' => 'web-application' ),
					'fas fa-file-powerpoint'=>array( 'group' => 'web-application' ),
					'fas fa-file-video'=>array( 'group' => 'web-application' ),
					'fas fa-file-word'=>array( 'group' => 'web-application' ),
					'fas fa-film'=>array( 'group' => 'web-application' ),
					'fas fa-filter'=>array( 'group' => 'web-application' ),
					'fas fa-fire'=>array( 'group' => 'web-application' ),
					'fas fa-fire-extinguisher'=>array( 'group' => 'web-application' ),
					'fas fa-first-aid'=>array( 'group' => 'web-application' ),
					'fas fa-flag'=>array( 'group' => 'web-application' ),
					'fas fa-flag-checkered'=>array( 'group' => 'web-application' ),
					'fas fa-flask'=>array( 'group' => 'web-application' ),
					'fas fa-folder'=>array( 'group' => 'web-application' ),
					'fas fa-folder-open'=>array( 'group' => 'web-application' ),
					'fas fa-font'=>array( 'group' => 'web-application' ),
					'fas fa-font-awesome-logo-full'=>array( 'group' => 'web-application' ),
					'fas fa-football-ball'=>array( 'group' => 'web-application' ),
					'fas fa-forward'=>array( 'group' => 'web-application' ),
					'fas fa-frog'=>array( 'group' => 'web-application' ),
					'fas fa-frown'=>array( 'group' => 'web-application' ),
					'fas fa-futbol'=>array( 'group' => 'web-application' ),
					'fas fa-gamepad'=>array( 'group' => 'web-application' ),
					'fas fa-gas-pump'=>array( 'group' => 'web-application' ),
					'fas fa-gavel'=>array( 'group' => 'web-application' ),
					'fas fa-gem'=>array( 'group' => 'web-application' ),
					'fas fa-genderless'=>array( 'group' => 'web-application' ),
					'fas fa-gift'=>array( 'group' => 'web-application' ),
					'fas fa-glass-martini'=>array( 'group' => 'web-application' ),
					'fas fa-glasses'=>array( 'group' => 'web-application' ),
					'fas fa-globe'=>array( 'group' => 'web-application' ),
					'fas fa-golf-ball'=>array( 'group' => 'web-application' ),
					'fas fa-graduation-cap'=>array( 'group' => 'web-application' ),
					'fas fa-greater-than'=>array( 'group' => 'web-application' ),
					'fas fa-greater-than-equal'=>array( 'group' => 'web-application' ),
					'fas fa-h-square'=>array( 'group' => 'web-application' ),
					'fas fa-hand-holding'=>array( 'group' => 'web-application' ),
					'fas fa-hand-holding-heart'=>array( 'group' => 'web-application' ),
					'fas fa-hand-holding-usd'=>array( 'group' => 'web-application' ),
					'fas fa-hand-lizard'=>array( 'group' => 'web-application' ),
					'fas fa-hand-paper'=>array( 'group' => 'web-application' ),
					'fas fa-hand-peace'=>array( 'group' => 'web-application' ),
					'fas fa-hand-point-down'=>array( 'group' => 'web-application' ),
					'fas fa-hand-point-left'=>array( 'group' => 'web-application' ),
					'fas fa-hand-point-right'=>array( 'group' => 'web-application' ),
					'fas fa-hand-point-up'=>array( 'group' => 'web-application' ),
					'fas fa-hand-pointer'=>array( 'group' => 'web-application' ),
					'fas fa-hand-rock'=>array( 'group' => 'web-application' ),
					'fas fa-hand-scissors'=>array( 'group' => 'web-application' ),
					'fas fa-hand-spock'=>array( 'group' => 'web-application' ),
					'fas fa-hands'=>array( 'group' => 'web-application' ),
					'fas fa-hands-helping'=>array( 'group' => 'web-application' ),
					'fas fa-handshake'=>array( 'group' => 'web-application' ),
					'fas fa-hashtag'=>array( 'group' => 'web-application' ),
					'fas fa-hdd'=>array( 'group' => 'web-application' ),
					'fas fa-heading'=>array( 'group' => 'web-application' ),
					'fas fa-headphones'=>array( 'group' => 'web-application' ),
					'fas fa-heart'=>array( 'group' => 'web-application' ),
					'fas fa-heartbeat'=>array( 'group' => 'web-application' ),
					'fas fa-helicopter'=>array( 'group' => 'web-application' ),
					'fas fa-history'=>array( 'group' => 'web-application' ),
					'fas fa-hockey-puck'=>array( 'group' => 'web-application' ),
					'fas fa-home'=>array( 'group' => 'web-application' ),
					'fas fa-hospital'=>array( 'group' => 'web-application' ),
					'fas fa-hospital-alt'=>array( 'group' => 'web-application' ),
					'fas fa-hospital-symbol'=>array( 'group' => 'web-application' ),
					'fas fa-hourglass'=>array( 'group' => 'web-application' ),
					'fas fa-hourglass-end'=>array( 'group' => 'web-application' ),
					'fas fa-hourglass-half'=>array( 'group' => 'web-application' ),
					'fas fa-hourglass-start'=>array( 'group' => 'web-application' ),
					'fas fa-i-cursor'=>array( 'group' => 'web-application' ),
					'fas fa-id-badge'=>array( 'group' => 'web-application' ),
					'fas fa-id-card'=>array( 'group' => 'web-application' ),
					'fas fa-id-card-alt'=>array( 'group' => 'web-application' ),
					'fas fa-image'=>array( 'group' => 'web-application' ),
					'fas fa-images'=>array( 'group' => 'web-application' ),
					'fas fa-inbox'=>array( 'group' => 'web-application' ),
					'fas fa-indent'=>array( 'group' => 'web-application' ),
					'fas fa-industry'=>array( 'group' => 'web-application' ),
					'fas fa-infinity'=>array( 'group' => 'web-application' ),
					'fas fa-info'=>array( 'group' => 'web-application' ),
					'fas fa-info-circle'=>array( 'group' => 'web-application' ),
					'fas fa-italic'=>array( 'group' => 'web-application' ),
					'fas fa-key'=>array( 'group' => 'web-application' ),
					'fas fa-keyboard'=>array( 'group' => 'web-application' ),
					'fas fa-kiwi-bird'=>array( 'group' => 'web-application' ),
					'fas fa-language'=>array( 'group' => 'web-application' ),
					'fas fa-laptop'=>array( 'group' => 'web-application' ),
					'fas fa-leaf'=>array( 'group' => 'web-application' ),
					'fas fa-lemon'=>array( 'group' => 'web-application' ),
					'fas fa-less-than'=>array( 'group' => 'web-application' ),
					'fas fa-less-than-equal'=>array( 'group' => 'web-application' ),
					'fas fa-level-down-alt'=>array( 'group' => 'web-application' ),
					'fas fa-level-up-alt'=>array( 'group' => 'web-application' ),
					'fas fa-life-ring'=>array( 'group' => 'web-application' ),
					'fas fa-lightbulb'=>array( 'group' => 'web-application' ),
					'fas fa-link'=>array( 'group' => 'web-application' ),
					'fas fa-lira-sign'=>array( 'group' => 'web-application' ),
					'fas fa-list'=>array( 'group' => 'web-application' ),
					'fas fa-list-alt'=>array( 'group' => 'web-application' ),
					'fas fa-list-ol'=>array( 'group' => 'web-application' ),
					'fas fa-list-ul'=>array( 'group' => 'web-application' ),
					'fas fa-location-arrow'=>array( 'group' => 'web-application' ),
					'fas fa-lock'=>array( 'group' => 'web-application' ),
					'fas fa-lock-open'=>array( 'group' => 'web-application' ),
					'fas fa-long-arrow-alt-down'=>array( 'group' => 'web-application' ),
					'fas fa-long-arrow-alt-left'=>array( 'group' => 'web-application' ),
					'fas fa-long-arrow-alt-right'=>array( 'group' => 'web-application' ),
					'fas fa-long-arrow-alt-up'=>array( 'group' => 'web-application' ),
					'fas fa-low-vision'=>array( 'group' => 'web-application' ),
					'fas fa-magic'=>array( 'group' => 'web-application' ),
					'fas fa-magnet'=>array( 'group' => 'web-application' ),
					'fas fa-male'=>array( 'group' => 'web-application' ),
					'fas fa-map'=>array( 'group' => 'web-application' ),
					'fas fa-map-marker'=>array( 'group' => 'web-application' ),
					'fas fa-map-marker-alt'=>array( 'group' => 'web-application' ),
					'fas fa-map-pin'=>array( 'group' => 'web-application' ),
					'fas fa-map-signs'=>array( 'group' => 'web-application' ),
					'fas fa-mars'=>array( 'group' => 'web-application' ),
					'fas fa-mars-double'=>array( 'group' => 'web-application' ),
					'fas fa-mars-stroke'=>array( 'group' => 'web-application' ),
					'fas fa-mars-stroke-h'=>array( 'group' => 'web-application' ),
					'fas fa-mars-stroke-v'=>array( 'group' => 'web-application' ),
					'fas fa-medkit'=>array( 'group' => 'web-application' ),
					'fas fa-meh'=>array( 'group' => 'web-application' ),
					'fas fa-memory'=>array( 'group' => 'web-application' ),
					'fas fa-mercury'=>array( 'group' => 'web-application' ),
					'fas fa-microchip'=>array( 'group' => 'web-application' ),
					'fas fa-microphone'=>array( 'group' => 'web-application' ),
					'fas fa-microphone-alt'=>array( 'group' => 'web-application' ),
					'fas fa-microphone-alt-slash'=>array( 'group' => 'web-application' ),
					'fas fa-microphone-slash'=>array( 'group' => 'web-application' ),
					'fas fa-minus'=>array( 'group' => 'web-application' ),
					'fas fa-minus-circle'=>array( 'group' => 'web-application' ),
					'fas fa-minus-square'=>array( 'group' => 'web-application' ),
					'fas fa-mobile'=>array( 'group' => 'web-application' ),
					'fas fa-mobile-alt'=>array( 'group' => 'web-application' ),
					'fas fa-money-bill'=>array( 'group' => 'web-application' ),
					'fas fa-money-bill-alt'=>array( 'group' => 'web-application' ),
					'fas fa-money-bill-wave'=>array( 'group' => 'web-application' ),
					'fas fa-money-bill-wave-alt'=>array( 'group' => 'web-application' ),
					'fas fa-money-check'=>array( 'group' => 'web-application' ),
					'fas fa-money-check-alt'=>array( 'group' => 'web-application' ),
					'fas fa-moon'=>array( 'group' => 'web-application' ),
					'fas fa-motorcycle'=>array( 'group' => 'web-application' ),
					'fas fa-mouse-pointer'=>array( 'group' => 'web-application' ),
					'fas fa-music'=>array( 'group' => 'web-application' ),
					'fas fa-neuter'=>array( 'group' => 'web-application' ),
					'fas fa-newspaper'=>array( 'group' => 'web-application' ),
					'fas fa-not-equal'=>array( 'group' => 'web-application' ),
					'fas fa-notes-medical'=>array( 'group' => 'web-application' ),
					'fas fa-object-group'=>array( 'group' => 'web-application' ),
					'fas fa-object-ungroup'=>array( 'group' => 'web-application' ),
					'fas fa-outdent'=>array( 'group' => 'web-application' ),
					'fas fa-paint-brush'=>array( 'group' => 'web-application' ),
					'fas fa-palette'=>array( 'group' => 'web-application' ),
					'fas fa-pallet'=>array( 'group' => 'web-application' ),
					'fas fa-paper-plane'=>array( 'group' => 'web-application' ),
					'fas fa-paperclip'=>array( 'group' => 'web-application' ),
					'fas fa-parachute-box'=>array( 'group' => 'web-application' ),
					'fas fa-paragraph'=>array( 'group' => 'web-application' ),
					'fas fa-parking'=>array( 'group' => 'web-application' ),
					'fas fa-paste'=>array( 'group' => 'web-application' ),
					'fas fa-pause'=>array( 'group' => 'web-application' ),
					'fas fa-pause-circle'=>array( 'group' => 'web-application' ),
					'fas fa-paw'=>array( 'group' => 'web-application' ),
					'fas fa-pen-square'=>array( 'group' => 'web-application' ),
					'fas fa-pencil-alt'=>array( 'group' => 'web-application' ),
					'fas fa-people-carry'=>array( 'group' => 'web-application' ),
					'fas fa-percent'=>array( 'group' => 'web-application' ),
					'fas fa-percentage'=>array( 'group' => 'web-application' ),
					'fas fa-phone'=>array( 'group' => 'web-application' ),
					'fas fa-phone-slash'=>array( 'group' => 'web-application' ),
					'fas fa-phone-square'=>array( 'group' => 'web-application' ),
					'fas fa-phone-volume'=>array( 'group' => 'web-application' ),
					'fas fa-piggy-bank'=>array( 'group' => 'web-application' ),
					'fas fa-pills'=>array( 'group' => 'web-application' ),
					'fas fa-plane'=>array( 'group' => 'web-application' ),
					'fas fa-play'=>array( 'group' => 'web-application' ),
					'fas fa-play-circle'=>array( 'group' => 'web-application' ),
					'fas fa-plug'=>array( 'group' => 'web-application' ),
					'fas fa-plus'=>array( 'group' => 'web-application' ),
					'fas fa-plus-circle'=>array( 'group' => 'web-application' ),
					'fas fa-plus-square'=>array( 'group' => 'web-application' ),
					'fas fa-podcast'=>array( 'group' => 'web-application' ),
					'fas fa-poo'=>array( 'group' => 'web-application' ),
					'fas fa-portrait'=>array( 'group' => 'web-application' ),
					'fas fa-pound-sign'=>array( 'group' => 'web-application' ),
					'fas fa-power-off'=>array( 'group' => 'web-application' ),
					'fas fa-prescription-bottle'=>array( 'group' => 'web-application' ),
					'fas fa-prescription-bottle-alt'=>array( 'group' => 'web-application' ),
					'fas fa-print'=>array( 'group' => 'web-application' ),
					'fas fa-procedures'=>array( 'group' => 'web-application' ),
					'fas fa-project-diagram'=>array( 'group' => 'web-application' ),
					'fas fa-puzzle-piece'=>array( 'group' => 'web-application' ),
					'fas fa-qrcode'=>array( 'group' => 'web-application' ),
					'fas fa-question'=>array( 'group' => 'web-application' ),
					'fas fa-question-circle'=>array( 'group' => 'web-application' ),
					'fas fa-quidditch'=>array( 'group' => 'web-application' ),
					'fas fa-quote-left'=>array( 'group' => 'web-application' ),
					'fas fa-quote-right'=>array( 'group' => 'web-application' ),
					'fas fa-random'=>array( 'group' => 'web-application' ),
					'fas fa-receipt'=>array( 'group' => 'web-application' ),
					'fas fa-recycle'=>array( 'group' => 'web-application' ),
					'fas fa-redo'=>array( 'group' => 'web-application' ),
					'fas fa-redo-alt'=>array( 'group' => 'web-application' ),
					'fas fa-registered'=>array( 'group' => 'web-application' ),
					'fas fa-reply'=>array( 'group' => 'web-application' ),
					'fas fa-reply-all'=>array( 'group' => 'web-application' ),
					'fas fa-retweet'=>array( 'group' => 'web-application' ),
					'fas fa-ribbon'=>array( 'group' => 'web-application' ),
					'fas fa-road'=>array( 'group' => 'web-application' ),
					'fas fa-robot'=>array( 'group' => 'web-application' ),
					'fas fa-rocket'=>array( 'group' => 'web-application' ),
					'fas fa-rss'=>array( 'group' => 'web-application' ),
					'fas fa-rss-square'=>array( 'group' => 'web-application' ),
					'fas fa-ruble-sign'=>array( 'group' => 'web-application' ),
					'fas fa-ruler'=>array( 'group' => 'web-application' ),
					'fas fa-ruler-combined'=>array( 'group' => 'web-application' ),
					'fas fa-ruler-horizontal'=>array( 'group' => 'web-application' ),
					'fas fa-ruler-vertical'=>array( 'group' => 'web-application' ),
					'fas fa-rupee-sign'=>array( 'group' => 'web-application' ),
					'fas fa-save'=>array( 'group' => 'web-application' ),
					'fas fa-school'=>array( 'group' => 'web-application' ),
					'fas fa-screwdriver'=>array( 'group' => 'web-application' ),
					'fas fa-search'=>array( 'group' => 'web-application' ),
					'fas fa-search-minus'=>array( 'group' => 'web-application' ),
					'fas fa-search-plus'=>array( 'group' => 'web-application' ),
					'fas fa-seedling'=>array( 'group' => 'web-application' ),
					'fas fa-server'=>array( 'group' => 'web-application' ),
					'fas fa-share'=>array( 'group' => 'web-application' ),
					'fas fa-share-alt'=>array( 'group' => 'web-application' ),
					'fas fa-share-alt-square'=>array( 'group' => 'web-application' ),
					'fas fa-share-square'=>array( 'group' => 'web-application' ),
					'fas fa-shekel-sign'=>array( 'group' => 'web-application' ),
					'fas fa-shield-alt'=>array( 'group' => 'web-application' ),
					'fas fa-ship'=>array( 'group' => 'web-application' ),
					'fas fa-shipping-fast'=>array( 'group' => 'web-application' ),
					'fas fa-shoe-prints'=>array( 'group' => 'web-application' ),
					'fas fa-shopping-bag'=>array( 'group' => 'web-application' ),
					'fas fa-shopping-basket'=>array( 'group' => 'web-application' ),
					'fas fa-shopping-cart'=>array( 'group' => 'web-application' ),
					'fas fa-shower'=>array( 'group' => 'web-application' ),
					'fas fa-sign'=>array( 'group' => 'web-application' ),
					'fas fa-sign-in-alt'=>array( 'group' => 'web-application' ),
					'fas fa-sign-language'=>array( 'group' => 'web-application' ),
					'fas fa-sign-out-alt'=>array( 'group' => 'web-application' ),
					'fas fa-signal'=>array( 'group' => 'web-application' ),
					'fas fa-sitemap'=>array( 'group' => 'web-application' ),
					'fas fa-skull'=>array( 'group' => 'web-application' ),
					'fas fa-sliders-h'=>array( 'group' => 'web-application' ),
					'fas fa-smile'=>array( 'group' => 'web-application' ),
					'fas fa-smoking'=>array( 'group' => 'web-application' ),
					'fas fa-smoking-ban'=>array( 'group' => 'web-application' ),
					'fas fa-snowflake'=>array( 'group' => 'web-application' ),
					'fas fa-sort'=>array( 'group' => 'web-application' ),
					'fas fa-sort-alpha-down'=>array( 'group' => 'web-application' ),
					'fas fa-sort-alpha-up'=>array( 'group' => 'web-application' ),
					'fas fa-sort-amount-down'=>array( 'group' => 'web-application' ),
					'fas fa-sort-amount-up'=>array( 'group' => 'web-application' ),
					'fas fa-sort-down'=>array( 'group' => 'web-application' ),
					'fas fa-sort-numeric-down'=>array( 'group' => 'web-application' ),
					'fas fa-sort-numeric-up'=>array( 'group' => 'web-application' ),
					'fas fa-sort-up'=>array( 'group' => 'web-application' ),
					'fas fa-space-shuttle'=>array( 'group' => 'web-application' ),
					'fas fa-spinner'=>array( 'group' => 'web-application' ),
					'fas fa-square'=>array( 'group' => 'web-application' ),
					'fas fa-square-full'=>array( 'group' => 'web-application' ),
					'fas fa-star'=>array( 'group' => 'web-application' ),
					'fas fa-star-half'=>array( 'group' => 'web-application' ),
					'fas fa-step-backward'=>array( 'group' => 'web-application' ),
					'fas fa-step-forward'=>array( 'group' => 'web-application' ),
					'fas fa-stethoscope'=>array( 'group' => 'web-application' ),
					'fas fa-sticky-note'=>array( 'group' => 'web-application' ),
					'fas fa-stop'=>array( 'group' => 'web-application' ),
					'fas fa-stop-circle'=>array( 'group' => 'web-application' ),
					'fas fa-stopwatch'=>array( 'group' => 'web-application' ),
					'fas fa-store'=>array( 'group' => 'web-application' ),
					'fas fa-store-alt'=>array( 'group' => 'web-application' ),
					'fas fa-stream'=>array( 'group' => 'web-application' ),
					'fas fa-street-view'=>array( 'group' => 'web-application' ),
					'fas fa-strikethrough'=>array( 'group' => 'web-application' ),
					'fas fa-stroopwafel'=>array( 'group' => 'web-application' ),
					'fas fa-subscript'=>array( 'group' => 'web-application' ),
					'fas fa-subway'=>array( 'group' => 'web-application' ),
					'fas fa-suitcase'=>array( 'group' => 'web-application' ),
					'fas fa-sun'=>array( 'group' => 'web-application' ),
					'fas fa-superscript'=>array( 'group' => 'web-application' ),
					'fas fa-sync'=>array( 'group' => 'web-application' ),
					'fas fa-sync-alt'=>array( 'group' => 'web-application' ),
					'fas fa-syringe'=>array( 'group' => 'web-application' ),
					'fas fa-table'=>array( 'group' => 'web-application' ),
					'fas fa-table-tennis'=>array( 'group' => 'web-application' ),
					'fas fa-tablet'=>array( 'group' => 'web-application' ),
					'fas fa-tablet-alt'=>array( 'group' => 'web-application' ),
					'fas fa-tablets'=>array( 'group' => 'web-application' ),
					'fas fa-tachometer-alt'=>array( 'group' => 'web-application' ),
					'fas fa-tag'=>array( 'group' => 'web-application' ),
					'fas fa-tags'=>array( 'group' => 'web-application' ),
					'fas fa-tape'=>array( 'group' => 'web-application' ),
					'fas fa-tasks'=>array( 'group' => 'web-application' ),
					'fas fa-taxi'=>array( 'group' => 'web-application' ),
					'fas fa-terminal'=>array( 'group' => 'web-application' ),
					'fas fa-text-height'=>array( 'group' => 'web-application' ),
					'fas fa-text-width'=>array( 'group' => 'web-application' ),
					'fas fa-th'=>array( 'group' => 'web-application' ),
					'fas fa-th-large'=>array( 'group' => 'web-application' ),
					'fas fa-th-list'=>array( 'group' => 'web-application' ),
					'fas fa-thermometer'=>array( 'group' => 'web-application' ),
					'fas fa-thermometer-empty'=>array( 'group' => 'web-application' ),
					'fas fa-thermometer-full'=>array( 'group' => 'web-application' ),
					'fas fa-thermometer-half'=>array( 'group' => 'web-application' ),
					'fas fa-thermometer-quarter'=>array( 'group' => 'web-application' ),
					'fas fa-thermometer-three-quarters'=>array( 'group' => 'web-application' ),
					'fas fa-thumbs-down'=>array( 'group' => 'web-application' ),
					'fas fa-thumbs-up'=>array( 'group' => 'web-application' ),
					'fas fa-thumbtack'=>array( 'group' => 'web-application' ),
					'fas fa-ticket-alt'=>array( 'group' => 'web-application' ),
					'fas fa-times'=>array( 'group' => 'web-application' ),
					'fas fa-times-circle'=>array( 'group' => 'web-application' ),
					'fas fa-tint'=>array( 'group' => 'web-application' ),
					'fas fa-toggle-off'=>array( 'group' => 'web-application' ),
					'fas fa-toggle-on'=>array( 'group' => 'web-application' ),
					'fas fa-toolbox'=>array( 'group' => 'web-application' ),
					'fas fa-trademark'=>array( 'group' => 'web-application' ),
					'fas fa-train'=>array( 'group' => 'web-application' ),
					'fas fa-transgender'=>array( 'group' => 'web-application' ),
					'fas fa-transgender-alt'=>array( 'group' => 'web-application' ),
					'fas fa-trash'=>array( 'group' => 'web-application' ),
					'fas fa-trash-alt'=>array( 'group' => 'web-application' ),
					'fas fa-tree'=>array( 'group' => 'web-application' ),
					'fas fa-trophy'=>array( 'group' => 'web-application' ),
					'fas fa-truck'=>array( 'group' => 'web-application' ),
					'fas fa-truck-loading'=>array( 'group' => 'web-application' ),
					'fas fa-truck-moving'=>array( 'group' => 'web-application' ),
					'fas fa-tshirt'=>array( 'group' => 'web-application' ),
					'fas fa-tty'=>array( 'group' => 'web-application' ),
					'fas fa-tv'=>array( 'group' => 'web-application' ),
					'fas fa-umbrella'=>array( 'group' => 'web-application' ),
					'fas fa-underline'=>array( 'group' => 'web-application' ),
					'fas fa-undo'=>array( 'group' => 'web-application' ),
					'fas fa-undo-alt'=>array( 'group' => 'web-application' ),
					'fas fa-universal-access'=>array( 'group' => 'web-application' ),
					'fas fa-university'=>array( 'group' => 'web-application' ),
					'fas fa-unlink'=>array( 'group' => 'web-application' ),
					'fas fa-unlock'=>array( 'group' => 'web-application' ),
					'fas fa-unlock-alt'=>array( 'group' => 'web-application' ),
					'fas fa-upload'=>array( 'group' => 'web-application' ),
					'fas fa-user'=>array( 'group' => 'web-application' ),
					'fas fa-user-alt'=>array( 'group' => 'web-application' ),
					'fas fa-user-alt-slash'=>array( 'group' => 'web-application' ),
					'fas fa-user-astronaut'=>array( 'group' => 'web-application' ),
					'fas fa-user-check'=>array( 'group' => 'web-application' ),
					'fas fa-user-circle'=>array( 'group' => 'web-application' ),
					'fas fa-user-clock'=>array( 'group' => 'web-application' ),
					'fas fa-user-cog'=>array( 'group' => 'web-application' ),
					'fas fa-user-edit'=>array( 'group' => 'web-application' ),
					'fas fa-user-friends'=>array( 'group' => 'web-application' ),
					'fas fa-user-graduate'=>array( 'group' => 'web-application' ),
					'fas fa-user-lock'=>array( 'group' => 'web-application' ),
					'fas fa-user-md'=>array( 'group' => 'web-application' ),
					'fas fa-user-minus'=>array( 'group' => 'web-application' ),
					'fas fa-user-ninja'=>array( 'group' => 'web-application' ),
					'fas fa-user-plus'=>array( 'group' => 'web-application' ),
					'fas fa-user-secret'=>array( 'group' => 'web-application' ),
					'fas fa-user-shield'=>array( 'group' => 'web-application' ),
					'fas fa-user-slash'=>array( 'group' => 'web-application' ),
					'fas fa-user-tag'=>array( 'group' => 'web-application' ),
					'fas fa-user-tie'=>array( 'group' => 'web-application' ),
					'fas fa-user-times'=>array( 'group' => 'web-application' ),
					'fas fa-users'=>array( 'group' => 'web-application' ),
					'fas fa-users-cog'=>array( 'group' => 'web-application' ),
					'fas fa-utensil-spoon'=>array( 'group' => 'web-application' ),
					'fas fa-utensils'=>array( 'group' => 'web-application' ),
					'fas fa-venus'=>array( 'group' => 'web-application' ),
					'fas fa-venus-double'=>array( 'group' => 'web-application' ),
					'fas fa-venus-mars'=>array( 'group' => 'web-application' ),
					'fas fa-vial'=>array( 'group' => 'web-application' ),
					'fas fa-vials'=>array( 'group' => 'web-application' ),
					'fas fa-video'=>array( 'group' => 'web-application' ),
					'fas fa-video-slash'=>array( 'group' => 'web-application' ),
					'fas fa-volleyball-ball'=>array( 'group' => 'web-application' ),
					'fas fa-volume-down'=>array( 'group' => 'web-application' ),
					'fas fa-volume-off'=>array( 'group' => 'web-application' ),
					'fas fa-volume-up'=>array( 'group' => 'web-application' ),
					'fas fa-walking'=>array( 'group' => 'web-application' ),
					'fas fa-wallet'=>array( 'group' => 'web-application' ),
					'fas fa-warehouse'=>array( 'group' => 'web-application' ),
					'fas fa-weight'=>array( 'group' => 'web-application' ),
					'fas fa-wheelchair'=>array( 'group' => 'web-application' ),
					'fas fa-wifi'=>array( 'group' => 'web-application' ),
					'fas fa-window-close'=>array( 'group' => 'web-application' ),
					'fas fa-window-maximize'=>array( 'group' => 'web-application' ),
					'fas fa-window-minimize'=>array( 'group' => 'web-application' ),
					'fas fa-window-restore'=>array( 'group' => 'web-application' ),
					'fas fa-wine-glass'=>array( 'group' => 'web-application' ),
					'fas fa-won-sign'=>array( 'group' => 'web-application' ),
					'fas fa-wrench'=>array( 'group' => 'web-application' ),
					'fas fa-x-ray'=>array( 'group' => 'web-application' ),
					'fas fa-yen-sign'=>array( 'group' => 'web-application' ),
					'far fa-address-book'=>array( 'group' => 'web-application' ),
					'far fa-address-card'=>array( 'group' => 'web-application' ),
					'far fa-arrow-alt-circle-down'=>array( 'group' => 'web-application' ),
					'far fa-arrow-alt-circle-left'=>array( 'group' => 'web-application' ),
					'far fa-arrow-alt-circle-right'=>array( 'group' => 'web-application' ),
					'far fa-arrow-alt-circle-up'=>array( 'group' => 'web-application' ),
					'far fa-bell'=>array( 'group' => 'web-application' ),
					'far fa-bell-slash'=>array( 'group' => 'web-application' ),
					'far fa-bookmark'=>array( 'group' => 'web-application' ),
					'far fa-building'=>array( 'group' => 'web-application' ),
					'far fa-calendar'=>array( 'group' => 'web-application' ),
					'far fa-calendar-alt'=>array( 'group' => 'web-application' ),
					'far fa-calendar-check'=>array( 'group' => 'web-application' ),
					'far fa-calendar-minus'=>array( 'group' => 'web-application' ),
					'far fa-calendar-plus'=>array( 'group' => 'web-application' ),
					'far fa-calendar-times'=>array( 'group' => 'web-application' ),
					'far fa-caret-square-down'=>array( 'group' => 'web-application' ),
					'far fa-caret-square-left'=>array( 'group' => 'web-application' ),
					'far fa-caret-square-right'=>array( 'group' => 'web-application' ),
					'far fa-caret-square-up'=>array( 'group' => 'web-application' ),
					'far fa-chart-bar'=>array( 'group' => 'web-application' ),
					'far fa-check-circle'=>array( 'group' => 'web-application' ),
					'far fa-check-square'=>array( 'group' => 'web-application' ),
					'far fa-circle'=>array( 'group' => 'web-application' ),
					'far fa-clipboard'=>array( 'group' => 'web-application' ),
					'far fa-clock'=>array( 'group' => 'web-application' ),
					'far fa-clone'=>array( 'group' => 'web-application' ),
					'far fa-closed-captioning'=>array( 'group' => 'web-application' ),
					'far fa-comment'=>array( 'group' => 'web-application' ),
					'far fa-comment-alt'=>array( 'group' => 'web-application' ),
					'far fa-comment-dots'=>array( 'group' => 'web-application' ),
					'far fa-comments'=>array( 'group' => 'web-application' ),
					'far fa-compass'=>array( 'group' => 'web-application' ),
					'far fa-copy'=>array( 'group' => 'web-application' ),
					'far fa-copyright'=>array( 'group' => 'web-application' ),
					'far fa-credit-card'=>array( 'group' => 'web-application' ),
					'far fa-dot-circle'=>array( 'group' => 'web-application' ),
					'far fa-edit'=>array( 'group' => 'web-application' ),
					'far fa-envelope'=>array( 'group' => 'web-application' ),
					'far fa-envelope-open'=>array( 'group' => 'web-application' ),
					'far fa-eye'=>array( 'group' => 'web-application' ),
					'far fa-eye-slash'=>array( 'group' => 'web-application' ),
					'far fa-file'=>array( 'group' => 'web-application' ),
					'far fa-file-alt'=>array( 'group' => 'web-application' ),
					'far fa-file-archive'=>array( 'group' => 'web-application' ),
					'far fa-file-audio'=>array( 'group' => 'web-application' ),
					'far fa-file-code'=>array( 'group' => 'web-application' ),
					'far fa-file-excel'=>array( 'group' => 'web-application' ),
					'far fa-file-image'=>array( 'group' => 'web-application' ),
					'far fa-file-pdf'=>array( 'group' => 'web-application' ),
					'far fa-file-powerpoint'=>array( 'group' => 'web-application' ),
					'far fa-file-video'=>array( 'group' => 'web-application' ),
					'far fa-file-word'=>array( 'group' => 'web-application' ),
					'far fa-flag'=>array( 'group' => 'web-application' ),
					'far fa-folder'=>array( 'group' => 'web-application' ),
					'far fa-folder-open'=>array( 'group' => 'web-application' ),
					'far fa-font-awesome-logo-full'=>array( 'group' => 'web-application' ),
					'far fa-frown'=>array( 'group' => 'web-application' ),
					'far fa-futbol'=>array( 'group' => 'web-application' ),
					'far fa-gem'=>array( 'group' => 'web-application' ),
					'far fa-hand-lizard'=>array( 'group' => 'web-application' ),
					'far fa-hand-paper'=>array( 'group' => 'web-application' ),
					'far fa-hand-peace'=>array( 'group' => 'web-application' ),
					'far fa-hand-point-down'=>array( 'group' => 'web-application' ),
					'far fa-hand-point-left'=>array( 'group' => 'web-application' ),
					'far fa-hand-point-right'=>array( 'group' => 'web-application' ),
					'far fa-hand-point-up'=>array( 'group' => 'web-application' ),
					'far fa-hand-pointer'=>array( 'group' => 'web-application' ),
					'far fa-hand-rock'=>array( 'group' => 'web-application' ),
					'far fa-hand-scissors'=>array( 'group' => 'web-application' ),
					'far fa-hand-spock'=>array( 'group' => 'web-application' ),
					'far fa-handshake'=>array( 'group' => 'web-application' ),
					'far fa-hdd'=>array( 'group' => 'web-application' ),
					'far fa-heart'=>array( 'group' => 'web-application' ),
					'far fa-hospital'=>array( 'group' => 'web-application' ),
					'far fa-hourglass'=>array( 'group' => 'web-application' ),
					'far fa-id-badge'=>array( 'group' => 'web-application' ),
					'far fa-id-card'=>array( 'group' => 'web-application' ),
					'far fa-image'=>array( 'group' => 'web-application' ),
					'far fa-images'=>array( 'group' => 'web-application' ),
					'far fa-keyboard'=>array( 'group' => 'web-application' ),
					'far fa-lemon'=>array( 'group' => 'web-application' ),
					'far fa-life-ring'=>array( 'group' => 'web-application' ),
					'far fa-lightbulb'=>array( 'group' => 'web-application' ),
					'far fa-list-alt'=>array( 'group' => 'web-application' ),
					'far fa-map'=>array( 'group' => 'web-application' ),
					'far fa-meh'=>array( 'group' => 'web-application' ),
					'far fa-minus-square'=>array( 'group' => 'web-application' ),
					'far fa-money-bill-alt'=>array( 'group' => 'web-application' ),
					'far fa-moon'=>array( 'group' => 'web-application' ),
					'far fa-newspaper'=>array( 'group' => 'web-application' ),
					'far fa-object-group'=>array( 'group' => 'web-application' ),
					'far fa-object-ungroup'=>array( 'group' => 'web-application' ),
					'far fa-paper-plane'=>array( 'group' => 'web-application' ),
					'far fa-pause-circle'=>array( 'group' => 'web-application' ),
					'far fa-play-circle'=>array( 'group' => 'web-application' ),
					'far fa-plus-square'=>array( 'group' => 'web-application' ),
					'far fa-question-circle'=>array( 'group' => 'web-application' ),
					'far fa-registered'=>array( 'group' => 'web-application' ),
					'far fa-save'=>array( 'group' => 'web-application' ),
					'far fa-share-square'=>array( 'group' => 'web-application' ),
					'far fa-smile'=>array( 'group' => 'web-application' ),
					'far fa-snowflake'=>array( 'group' => 'web-application' ),
					'far fa-square'=>array( 'group' => 'web-application' ),
					'far fa-star'=>array( 'group' => 'web-application' ),
					'far fa-star-half'=>array( 'group' => 'web-application' ),
					'far fa-sticky-note'=>array( 'group' => 'web-application' ),
					'far fa-stop-circle'=>array( 'group' => 'web-application' ),
					'far fa-sun'=>array( 'group' => 'web-application' ),
					'far fa-thumbs-down'=>array( 'group' => 'web-application' ),
					'far fa-thumbs-up'=>array( 'group' => 'web-application' ),
					'far fa-times-circle'=>array( 'group' => 'web-application' ),
					'far fa-trash-alt'=>array( 'group' => 'web-application' ),
					'far fa-user'=>array( 'group' => 'web-application' ),
					'far fa-user-circle'=>array( 'group' => 'web-application' ),
					'far fa-window-close'=>array( 'group' => 'web-application' ),
					'far fa-window-maximize'=>array( 'group' => 'web-application' ),
					'far fa-window-minimize'=>array( 'group' => 'web-application' ),
					'far fa-window-restore'=>array( 'group' => 'web-application' ),
					'fab fa-500px'=>array( 'group' => 'web-application' ),
					'fab fa-accessible-icon'=>array( 'group' => 'web-application' ),
					'fab fa-accusoft'=>array( 'group' => 'web-application' ),
					'fab fa-adn'=>array( 'group' => 'web-application' ),
					'fab fa-adversal'=>array( 'group' => 'web-application' ),
					'fab fa-affiliatetheme'=>array( 'group' => 'web-application' ),
					'fab fa-algolia'=>array( 'group' => 'web-application' ),
					'fab fa-amazon'=>array( 'group' => 'web-application' ),
					'fab fa-amazon-pay'=>array( 'group' => 'web-application' ),
					'fab fa-amilia'=>array( 'group' => 'web-application' ),
					'fab fa-android'=>array( 'group' => 'web-application' ),
					'fab fa-angellist'=>array( 'group' => 'web-application' ),
					'fab fa-angrycreative'=>array( 'group' => 'web-application' ),
					'fab fa-angular'=>array( 'group' => 'web-application' ),
					'fab fa-app-store'=>array( 'group' => 'web-application' ),
					'fab fa-app-store-ios'=>array( 'group' => 'web-application' ),
					'fab fa-apper'=>array( 'group' => 'web-application' ),
					'fab fa-apple'=>array( 'group' => 'brand' ),
					'fab fa-apple-pay'=>array( 'group' => 'brand' ),
					'fab fa-asymmetrik'=>array( 'group' => 'web-application' ),
					'fab fa-audible'=>array( 'group' => 'web-application' ),
					'fab fa-autoprefixer'=>array( 'group' => 'web-application' ),
					'fab fa-avianex'=>array( 'group' => 'web-application' ),
					'fab fa-aviato'=>array( 'group' => 'web-application' ),
					'fab fa-aws'=>array( 'group' => 'web-application' ),
					'fab fa-bandcamp'=>array( 'group' => 'web-application' ),
					'fab fa-behance'=>array( 'group' => 'web-application' ),
					'fab fa-behance-square'=>array( 'group' => 'web-application' ),
					'fab fa-bimobject'=>array( 'group' => 'web-application' ),
					'fab fa-bitbucket'=>array( 'group' => 'web-application' ),
					'fab fa-bitcoin'=>array( 'group' => 'web-application' ),
					'fab fa-bity'=>array( 'group' => 'web-application' ),
					'fab fa-black-tie'=>array( 'group' => 'web-application' ),
					'fab fa-blackberry'=>array( 'group' => 'web-application' ),
					'fab fa-blogger'=>array( 'group' => 'web-application' ),
					'fab fa-blogger-b'=>array( 'group' => 'web-application' ),
					'fab fa-bluetooth'=>array( 'group' => 'web-application' ),
					'fab fa-bluetooth-b'=>array( 'group' => 'web-application' ),
					'fab fa-btc'=>array( 'group' => 'web-application' ),
					'fab fa-buromobelexperte'=>array( 'group' => 'web-application' ),
					'fab fa-buysellads'=>array( 'group' => 'web-application' ),
					'fab fa-cc-amazon-pay'=>array( 'group' => 'web-application' ),
					'fab fa-cc-amex'=>array( 'group' => 'web-application' ),
					'fab fa-cc-apple-pay'=>array( 'group' => 'web-application' ),
					'fab fa-cc-diners-club'=>array( 'group' => 'web-application' ),
					'fab fa-cc-discover'=>array( 'group' => 'web-application' ),
					'fab fa-cc-jcb'=>array( 'group' => 'web-application' ),
					'fab fa-cc-mastercard'=>array( 'group' => 'web-application' ),
					'fab fa-cc-paypal'=>array( 'group' => 'web-application' ),
					'fab fa-cc-stripe'=>array( 'group' => 'web-application' ),
					'fab fa-cc-visa'=>array( 'group' => 'web-application' ),
					'fab fa-centercode'=>array( 'group' => 'web-application' ),
					'fab fa-chrome'=>array( 'group' => 'web-application' ),
					'fab fa-cloudscale'=>array( 'group' => 'web-application' ),
					'fab fa-cloudsmith'=>array( 'group' => 'web-application' ),
					'fab fa-cloudversify'=>array( 'group' => 'web-application' ),
					'fab fa-codepen'=>array( 'group' => 'web-application' ),
					'fab fa-codiepie'=>array( 'group' => 'web-application' ),
					'fab fa-connectdevelop'=>array( 'group' => 'web-application' ),
					'fab fa-contao'=>array( 'group' => 'web-application' ),
					'fab fa-cpanel'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-by'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-nc'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-nc-eu'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-nc-jp'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-nd'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-pd'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-pd-alt'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-remix'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-sa'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-sampling'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-sampling-plus'=>array( 'group' => 'web-application' ),
					'fab fa-creative-commons-share'=>array( 'group' => 'web-application' ),
					'fab fa-css3'=>array( 'group' => 'web-application' ),
					'fab fa-css3-alt'=>array( 'group' => 'web-application' ),
					'fab fa-cuttlefish'=>array( 'group' => 'web-application' ),
					'fab fa-d-and-d'=>array( 'group' => 'web-application' ),
					'fab fa-dashcube'=>array( 'group' => 'web-application' ),
					'fab fa-delicious'=>array( 'group' => 'web-application' ),
					'fab fa-deploydog'=>array( 'group' => 'web-application' ),
					'fab fa-deskpro'=>array( 'group' => 'web-application' ),
					'fab fa-deviantart'=>array( 'group' => 'web-application' ),
					'fab fa-digg'=>array( 'group' => 'web-application' ),
					'fab fa-digital-ocean'=>array( 'group' => 'web-application' ),
					'fab fa-discord'=>array( 'group' => 'web-application' ),
					'fab fa-discourse'=>array( 'group' => 'web-application' ),
					'fab fa-dochub'=>array( 'group' => 'web-application' ),
					'fab fa-docker'=>array( 'group' => 'web-application' ),
					'fab fa-draft2digital'=>array( 'group' => 'web-application' ),
					'fab fa-dribbble'=>array( 'group' => 'brand' ),
					'fab fa-dribbble-square'=>array( 'group' => 'brand' ),
					'fab fa-dropbox'=>array( 'group' => 'web-application' ),
					'fab fa-drupal'=>array( 'group' => 'web-application' ),
					'fab fa-dyalog'=>array( 'group' => 'web-application' ),
					'fab fa-earlybirds'=>array( 'group' => 'web-application' ),
					'fab fa-ebay'=>array( 'group' => 'web-application' ),
					'fab fa-edge'=>array( 'group' => 'web-application' ),
					'fab fa-elementor'=>array( 'group' => 'web-application' ),
					'fab fa-ember'=>array( 'group' => 'web-application' ),
					'fab fa-empire'=>array( 'group' => 'web-application' ),
					'fab fa-envira'=>array( 'group' => 'web-application' ),
					'fab fa-erlang'=>array( 'group' => 'web-application' ),
					'fab fa-ethereum'=>array( 'group' => 'web-application' ),
					'fab fa-etsy'=>array( 'group' => 'web-application' ),
					'fab fa-expeditedssl'=>array( 'group' => 'web-application' ),
					'fab fa-facebook'=>array( 'group' => 'web-application' ),
					'fab fa-facebook-f'=>array( 'group' => 'web-application' ),
					'fab fa-facebook-messenger'=>array( 'group' => 'web-application' ),
					'fab fa-facebook-square'=>array( 'group' => 'web-application' ),
					'fab fa-firefox'=>array( 'group' => 'web-application' ),
					'fab fa-first-order'=>array( 'group' => 'web-application' ),
					'fab fa-first-order-alt'=>array( 'group' => 'web-application' ),
					'fab fa-firstdraft'=>array( 'group' => 'web-application' ),
					'fab fa-flickr'=>array( 'group' => 'web-application' ),
					'fab fa-flipboard'=>array( 'group' => 'web-application' ),
					'fab fa-fly'=>array( 'group' => 'web-application' ),
					'fab fa-font-awesome'=>array( 'group' => 'web-application' ),
					'fab fa-font-awesome-alt'=>array( 'group' => 'web-application' ),
					'fab fa-font-awesome-flag'=>array( 'group' => 'web-application' ),
					'fab fa-font-awesome-logo-full'=>array( 'group' => 'web-application' ),
					'fab fa-fonticons'=>array( 'group' => 'web-application' ),
					'fab fa-fonticons-fi'=>array( 'group' => 'web-application' ),
					'fab fa-fort-awesome'=>array( 'group' => 'web-application' ),
					'fab fa-fort-awesome-alt'=>array( 'group' => 'web-application' ),
					'fab fa-forumbee'=>array( 'group' => 'web-application' ),
					'fab fa-foursquare'=>array( 'group' => 'web-application' ),
					'fab fa-free-code-camp'=>array( 'group' => 'web-application' ),
					'fab fa-freebsd'=>array( 'group' => 'web-application' ),
					'fab fa-fulcrum'=>array( 'group' => 'web-application' ),
					'fab fa-galactic-republic'=>array( 'group' => 'web-application' ),
					'fab fa-galactic-senate'=>array( 'group' => 'web-application' ),
					'fab fa-get-pocket'=>array( 'group' => 'web-application' ),
					'fab fa-gg'=>array( 'group' => 'web-application' ),
					'fab fa-gg-circle'=>array( 'group' => 'web-application' ),
					'fab fa-git'=>array( 'group' => 'web-application' ),
					'fab fa-git-square'=>array( 'group' => 'web-application' ),
					'fab fa-github'=>array( 'group' => 'web-application' ),
					'fab fa-github-alt'=>array( 'group' => 'web-application' ),
					'fab fa-github-square'=>array( 'group' => 'web-application' ),
					'fab fa-gitkraken'=>array( 'group' => 'web-application' ),
					'fab fa-gitlab'=>array( 'group' => 'web-application' ),
					'fab fa-gitter'=>array( 'group' => 'web-application' ),
					'fab fa-glide'=>array( 'group' => 'web-application' ),
					'fab fa-glide-g'=>array( 'group' => 'web-application' ),
					'fab fa-gofore'=>array( 'group' => 'web-application' ),
					'fab fa-goodreads'=>array( 'group' => 'web-application' ),
					'fab fa-goodreads-g'=>array( 'group' => 'web-application' ),
					'fab fa-google'=>array( 'group' => 'web-application' ),
					'fab fa-google-drive'=>array( 'group' => 'web-application' ),
					'fab fa-google-play'=>array( 'group' => 'web-application' ),
					'fab fa-google-plus'=>array( 'group' => 'web-application' ),
					'fab fa-google-plus-g'=>array( 'group' => 'web-application' ),
					'fab fa-google-plus-square'=>array( 'group' => 'web-application' ),
					'fab fa-google-wallet'=>array( 'group' => 'web-application' ),
					'fab fa-gratipay'=>array( 'group' => 'web-application' ),
					'fab fa-grav'=>array( 'group' => 'web-application' ),
					'fab fa-gripfire'=>array( 'group' => 'web-application' ),
					'fab fa-grunt'=>array( 'group' => 'web-application' ),
					'fab fa-gulp'=>array( 'group' => 'web-application' ),
					'fab fa-hacker-news'=>array( 'group' => 'web-application' ),
					'fab fa-hacker-news-square'=>array( 'group' => 'web-application' ),
					'fab fa-hips'=>array( 'group' => 'web-application' ),
					'fab fa-hire-a-helper'=>array( 'group' => 'web-application' ),
					'fab fa-hooli'=>array( 'group' => 'web-application' ),
					'fab fa-hotjar'=>array( 'group' => 'web-application' ),
					'fab fa-houzz'=>array( 'group' => 'web-application' ),
					'fab fa-html5'=>array( 'group' => 'web-application' ),
					'fab fa-hubspot'=>array( 'group' => 'web-application' ),
					'fab fa-imdb'=>array( 'group' => 'web-application' ),
					'fab fa-instagram'=>array( 'group' => 'web-application' ),
					'fab fa-internet-explorer'=>array( 'group' => 'web-application' ),
					'fab fa-ioxhost'=>array( 'group' => 'web-application' ),
					'fab fa-itunes'=>array( 'group' => 'web-application' ),
					'fab fa-itunes-note'=>array( 'group' => 'web-application' ),
					'fab fa-java'=>array( 'group' => 'web-application' ),
					'fab fa-jedi-order'=>array( 'group' => 'web-application' ),
					'fab fa-jenkins'=>array( 'group' => 'web-application' ),
					'fab fa-joget'=>array( 'group' => 'web-application' ),
					'fab fa-joomla'=>array( 'group' => 'web-application' ),
					'fab fa-js'=>array( 'group' => 'web-application' ),
					'fab fa-js-square'=>array( 'group' => 'web-application' ),
					'fab fa-jsfiddle'=>array( 'group' => 'web-application' ),
					'fab fa-keybase'=>array( 'group' => 'web-application' ),
					'fab fa-keycdn'=>array( 'group' => 'web-application' ),
					'fab fa-kickstarter'=>array( 'group' => 'web-application' ),
					'fab fa-kickstarter-k'=>array( 'group' => 'web-application' ),
					'fab fa-korvue'=>array( 'group' => 'web-application' ),
					'fab fa-laravel'=>array( 'group' => 'web-application' ),
					'fab fa-lastfm'=>array( 'group' => 'web-application' ),
					'fab fa-lastfm-square'=>array( 'group' => 'web-application' ),
					'fab fa-leanpub'=>array( 'group' => 'web-application' ),
					'fab fa-less'=>array( 'group' => 'web-application' ),
					'fab fa-line'=>array( 'group' => 'web-application' ),
					'fab fa-linkedin'=>array( 'group' => 'web-application' ),
					'fab fa-linkedin-in'=>array( 'group' => 'web-application' ),
					'fab fa-linode'=>array( 'group' => 'web-application' ),
					'fab fa-linux'=>array( 'group' => 'web-application' ),
					'fab fa-lyft'=>array( 'group' => 'web-application' ),
					'fab fa-magento'=>array( 'group' => 'web-application' ),
					'fab fa-mandalorian'=>array( 'group' => 'web-application' ),
					'fab fa-mastodon'=>array( 'group' => 'web-application' ),
					'fab fa-maxcdn'=>array( 'group' => 'web-application' ),
					'fab fa-medapps'=>array( 'group' => 'web-application' ),
					'fab fa-medium'=>array( 'group' => 'web-application' ),
					'fab fa-medium-m'=>array( 'group' => 'web-application' ),
					'fab fa-medrt'=>array( 'group' => 'web-application' ),
					'fab fa-meetup'=>array( 'group' => 'web-application' ),
					'fab fa-microsoft'=>array( 'group' => 'web-application' ),
					'fab fa-mix'=>array( 'group' => 'web-application' ),
					'fab fa-mixcloud'=>array( 'group' => 'web-application' ),
					'fab fa-mizuni'=>array( 'group' => 'web-application' ),
					'fab fa-modx'=>array( 'group' => 'web-application' ),
					'fab fa-monero'=>array( 'group' => 'web-application' ),
					'fab fa-napster'=>array( 'group' => 'web-application' ),
					'fab fa-nintendo-switch'=>array( 'group' => 'web-application' ),
					'fab fa-node'=>array( 'group' => 'web-application' ),
					'fab fa-node-js'=>array( 'group' => 'web-application' ),
					'fab fa-npm'=>array( 'group' => 'web-application' ),
					'fab fa-ns8'=>array( 'group' => 'web-application' ),
					'fab fa-nutritionix'=>array( 'group' => 'web-application' ),
					'fab fa-odnoklassniki'=>array( 'group' => 'web-application' ),
					'fab fa-odnoklassniki-square'=>array( 'group' => 'web-application' ),
					'fab fa-old-republic'=>array( 'group' => 'web-application' ),
					'fab fa-opencart'=>array( 'group' => 'web-application' ),
					'fab fa-openid'=>array( 'group' => 'web-application' ),
					'fab fa-opera'=>array( 'group' => 'web-application' ),
					'fab fa-optin-monster'=>array( 'group' => 'web-application' ),
					'fab fa-osi'=>array( 'group' => 'web-application' ),
					'fab fa-page4'=>array( 'group' => 'web-application' ),
					'fab fa-pagelines'=>array( 'group' => 'web-application' ),
					'fab fa-palfed'=>array( 'group' => 'web-application' ),
					'fab fa-patreon'=>array( 'group' => 'web-application' ),
					'fab fa-paypal'=>array( 'group' => 'web-application' ),
					'fab fa-periscope'=>array( 'group' => 'web-application' ),
					'fab fa-phabricator'=>array( 'group' => 'web-application' ),
					'fab fa-phoenix-framework'=>array( 'group' => 'web-application' ),
					'fab fa-phoenix-squadron'=>array( 'group' => 'web-application' ),
					'fab fa-php'=>array( 'group' => 'web-application' ),
					'fab fa-pied-piper'=>array( 'group' => 'web-application' ),
					'fab fa-pied-piper-alt'=>array( 'group' => 'web-application' ),
					'fab fa-pied-piper-hat'=>array( 'group' => 'web-application' ),
					'fab fa-pied-piper-pp'=>array( 'group' => 'web-application' ),
					'fab fa-pinterest'=>array( 'group' => 'web-application' ),
					'fab fa-pinterest-p'=>array( 'group' => 'web-application' ),
					'fab fa-pinterest-square'=>array( 'group' => 'web-application' ),
					'fab fa-playstation'=>array( 'group' => 'web-application' ),
					'fab fa-product-hunt'=>array( 'group' => 'web-application' ),
					'fab fa-pushed'=>array( 'group' => 'web-application' ),
					'fab fa-python'=>array( 'group' => 'web-application' ),
					'fab fa-qq'=>array( 'group' => 'web-application' ),
					'fab fa-quinscape'=>array( 'group' => 'web-application' ),
					'fab fa-quora'=>array( 'group' => 'web-application' ),
					'fab fa-r-project'=>array( 'group' => 'web-application' ),
					'fab fa-ravelry'=>array( 'group' => 'web-application' ),
					'fab fa-react'=>array( 'group' => 'web-application' ),
					'fab fa-readme'=>array( 'group' => 'web-application' ),
					'fab fa-rebel'=>array( 'group' => 'web-application' ),
					'fab fa-red-river'=>array( 'group' => 'web-application' ),
					'fab fa-reddit'=>array( 'group' => 'web-application' ),
					'fab fa-reddit-alien'=>array( 'group' => 'web-application' ),
					'fab fa-reddit-square'=>array( 'group' => 'web-application' ),
					'fab fa-rendact'=>array( 'group' => 'web-application' ),
					'fab fa-renren'=>array( 'group' => 'web-application' ),
					'fab fa-replyd'=>array( 'group' => 'web-application' ),
					'fab fa-researchgate'=>array( 'group' => 'web-application' ),
					'fab fa-resolving'=>array( 'group' => 'web-application' ),
					'fab fa-rocketchat'=>array( 'group' => 'web-application' ),
					'fab fa-rockrms'=>array( 'group' => 'web-application' ),
					'fab fa-safari'=>array( 'group' => 'web-application' ),
					'fab fa-sass'=>array( 'group' => 'web-application' ),
					'fab fa-schlix'=>array( 'group' => 'web-application' ),
					'fab fa-scribd'=>array( 'group' => 'web-application' ),
					'fab fa-searchengin'=>array( 'group' => 'web-application' ),
					'fab fa-sellcast'=>array( 'group' => 'web-application' ),
					'fab fa-sellsy'=>array( 'group' => 'web-application' ),
					'fab fa-servicestack'=>array( 'group' => 'web-application' ),
					'fab fa-shirtsinbulk'=>array( 'group' => 'web-application' ),
					'fab fa-simplybuilt'=>array( 'group' => 'web-application' ),
					'fab fa-sistrix'=>array( 'group' => 'web-application' ),
					'fab fa-sith'=>array( 'group' => 'web-application' ),
					'fab fa-skyatlas'=>array( 'group' => 'web-application' ),
					'fab fa-skype'=>array( 'group' => 'web-application' ),
					'fab fa-slack'=>array( 'group' => 'web-application' ),
					'fab fa-slack-hash'=>array( 'group' => 'web-application' ),
					'fab fa-slideshare'=>array( 'group' => 'web-application' ),
					'fab fa-snapchat'=>array( 'group' => 'web-application' ),
					'fab fa-snapchat-ghost'=>array( 'group' => 'web-application' ),
					'fab fa-snapchat-square'=>array( 'group' => 'web-application' ),
					'fab fa-soundcloud'=>array( 'group' => 'web-application' ),
					'fab fa-speakap'=>array( 'group' => 'web-application' ),
					'fab fa-spotify'=>array( 'group' => 'web-application' ),
					'fab fa-stack-exchange'=>array( 'group' => 'web-application' ),
					'fab fa-stack-overflow'=>array( 'group' => 'web-application' ),
					'fab fa-staylinked'=>array( 'group' => 'web-application' ),
					'fab fa-steam'=>array( 'group' => 'web-application' ),
					'fab fa-steam-square'=>array( 'group' => 'web-application' ),
					'fab fa-steam-symbol'=>array( 'group' => 'web-application' ),
					'fab fa-sticker-mule'=>array( 'group' => 'web-application' ),
					'fab fa-strava'=>array( 'group' => 'web-application' ),
					'fab fa-stripe'=>array( 'group' => 'web-application' ),
					'fab fa-stripe-s'=>array( 'group' => 'web-application' ),
					'fab fa-studiovinari'=>array( 'group' => 'web-application' ),
					'fab fa-stumbleupon'=>array( 'group' => 'web-application' ),
					'fab fa-stumbleupon-circle'=>array( 'group' => 'web-application' ),
					'fab fa-superpowers'=>array( 'group' => 'web-application' ),
					'fab fa-supple'=>array( 'group' => 'web-application' ),
					'fab fa-teamspeak'=>array( 'group' => 'web-application' ),
					'fab fa-telegram'=>array( 'group' => 'web-application' ),
					'fab fa-telegram-plane'=>array( 'group' => 'web-application' ),
					'fab fa-tencent-weibo'=>array( 'group' => 'web-application' ),
					'fab fa-themeisle'=>array( 'group' => 'web-application' ),
					'fab fa-trade-federation'=>array( 'group' => 'web-application' ),
					'fab fa-trello'=>array( 'group' => 'web-application' ),
					'fab fa-tripadvisor'=>array( 'group' => 'web-application' ),
					'fab fa-tumblr'=>array( 'group' => 'web-application' ),
					'fab fa-tumblr-square'=>array( 'group' => 'web-application' ),
					'fab fa-twitch'=>array( 'group' => 'brand' ),
					'fab fa-twitter'=>array( 'group' => 'brand' ),
					'fab fa-twitter-square'=>array( 'group' => 'web-application' ),
					'fab fa-typo3'=>array( 'group' => 'web-application' ),
					'fab fa-uber'=>array( 'group' => 'web-application' ),
					'fab fa-uikit'=>array( 'group' => 'web-application' ),
					'fab fa-uniregistry'=>array( 'group' => 'web-application' ),
					'fab fa-untappd'=>array( 'group' => 'web-application' ),
					'fab fa-usb'=>array( 'group' => 'web-application' ),
					'fab fa-ussunnah'=>array( 'group' => 'web-application' ),
					'fab fa-vaadin'=>array( 'group' => 'web-application' ),
					'fab fa-viacoin'=>array( 'group' => 'web-application' ),
					'fab fa-viadeo'=>array( 'group' => 'web-application' ),
					'fab fa-viadeo-square'=>array( 'group' => 'web-application' ),
					'fab fa-viber'=>array( 'group' => 'web-application' ),
					'fab fa-vimeo'=>array( 'group' => 'web-application' ),
					'fab fa-vimeo-square'=>array( 'group' => 'web-application' ),
					'fab fa-vimeo-v'=>array( 'group' => 'web-application' ),
					'fab fa-vine'=>array( 'group' => 'web-application' ),
					'fab fa-vk'=>array( 'group' => 'web-application' ),
					'fab fa-vnv'=>array( 'group' => 'web-application' ),
					'fab fa-vuejs'=>array( 'group' => 'web-application' ),
					'fab fa-weibo'=>array( 'group' => 'web-application' ),
					'fab fa-weixin'=>array( 'group' => 'web-application' ),
					'fab fa-whatsapp'=>array( 'group' => 'web-application' ),
					'fab fa-whatsapp-square'=>array( 'group' => 'web-application' ),
					'fab fa-whmcs'=>array( 'group' => 'web-application' ),
					'fab fa-wikipedia-w'=>array( 'group' => 'web-application' ),
					'fab fa-windows'=>array( 'group' => 'web-application' ),
					'fab fa-wolf-pack-battalion'=>array( 'group' => 'web-application' ),
					'fab fa-wordpress'=>array( 'group' => 'web-application' ),
					'fab fa-wordpress-simple'=>array( 'group' => 'web-application' ),
					'fab fa-wpbeginner'=>array( 'group' => 'web-application' ),
					'fab fa-wpexplorer'=>array( 'group' => 'web-application' ),
					'fab fa-wpforms'=>array( 'group' => 'web-application' ),
					'fab fa-xbox'=>array( 'group' => 'web-application' ),
					'fab fa-xing'=>array( 'group' => 'web-application' ),
					'fab fa-xing-square'=>array( 'group' => 'web-application' ),
					'fab fa-y-combinator'=>array( 'group' => 'web-application' ),
					'fab fa-yahoo'=>array( 'group' => 'web-application' ),
					'fab fa-yandex'=>array( 'group' => 'web-application' ),
					'fab fa-yandex-international'=>array( 'group' => 'web-application' ),
					'fab fa-yelp'=>array( 'group' => 'web-application' ),
					'fab fa-yoast'=>array( 'group' => 'web-application' ),
					'fab fa-youtube'=>array( 'group' => 'brand' ),
					'fab fa-youtube-square'=>array( 'group' => 'brand' ),
				],
			),
		);
	}

}

FW_Option_Type::register( 'FW_Option_Type_NewIcon' );
